ImagePdfParams class

Parameters for generateImagePdf.

Constructors

ImagePdfParams({required Uint8List imageBytes, required double pageWidth, required double pageHeight, required double marginTop, required double marginBottom, required double marginLeft, required double marginRight})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
imageBytes Uint8List
Raw image bytes (JPEG, PNG, or GIF).
final
marginBottom double
final
marginLeft double
final
marginRight double
final
marginTop double
final
pageHeight double
final
pageWidth double
Page dimensions and margins.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited