SnackbarConfig class

Configuration for snackbar notifications.

Constructors

SnackbarConfig({Color textColor = Colors.black, Color? backgroundColor, Color actionTextColor = Colors.black, Duration duration = const Duration(seconds: 3), double borderRadius = 10.0})
Creates a configuration for controlling the appearance and behaviour of snackbars.
const

Properties

actionTextColor Color
Text colour for action buttons in snackbar.
final
backgroundColor Color?
Background colour for snackbar. If null, will default to theme-based colours.
final
borderRadius double
Border radius for snackbar corners.
final
duration Duration
Duration to show the snackbar.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color
Text colour for snackbar content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited