showMenuLayoutPreferences property
Whether to show the Menu layout button in the About dialogue.
Implementation
final bool showMenuLayoutPreferences;
Whether to show the Menu layout button in the About dialogue.
final bool showMenuLayoutPreferences;