SolidCustomStatusBarItem class

Configuration for additional custom status bar items.

Constructors

SolidCustomStatusBarItem({required String id, required Widget widget, int priority = 0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this status bar item.
final
priority int
Priority for ordering (higher numbers appear later).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget
The widget to display in the status bar.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited