title property
The login text indicating what we are loging in to, the URI of the user's webID used to identify the Solid server to authenticate against, and the URL used as the value of the Visit link. Visit the link by clicking info button.
Implementation
final String title, webID, link;