SolidMenuItem class

Simplified menu item configuration.

Constructors

SolidMenuItem({required String title, required IconData icon, SolidNavIconBuilder? iconBuilder, Color? color, Widget? child, String? tooltip, String? message, String? dialogTitle, void onTap(BuildContext)?, bool showInOverflow = false})
const

Properties

child → Widget?
Optional child widget (displayed when menu is selected).
final
color → Color?
Optional icon colour.
final
dialogTitle → String?
Optional dialogue title.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
Menu icon.
final
iconBuilder → SolidNavIconBuilder?
Optionally draws the menu icon instead of icon, which is then only a fallback: an avatar, a badge, anything that isn't a glyph in an icon font. Given the size and colour each menu surface would use.
final
message → String?
Optional message dialogue content.
final
onTap → void Function(BuildContext)?
Optional tap callback.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showInOverflow → bool
Whether this menu item should be moved into the overflow "More" menu on the bottom navigation bar, which is used on narrow screens on every platform.
final
title → String
Menu title.
final
tooltip → String?
Optional tooltip.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited