SolidThemeConfig class

Configuration for customising SolidUI theme.

Constructors

SolidThemeConfig({Color primaryColor = SolidTheme.primaryColor, double defaultPadding = SolidTheme.defaultPadding, double defaultBorderRadius = SolidTheme.defaultBorderRadius, Color primaryTextColor = SolidTheme.primaryTextColor, Color secondaryTextColor = SolidTheme.secondaryTextColor})
Creates a theme configuration.
const

Properties

darkTheme ThemeData
Creates dark theme based on this configuration.
no setter
defaultBorderRadius double
Default border radius for UI elements.
final
defaultPadding double
Default padding used throughout the application.
final
hashCode int
The hash code for this object.
no setterinherited
lightTheme ThemeData
Creates light and dark themes based on this configuration.
no setter
primaryColor Color
Primary color for the application.
final
primaryTextColor Color
Text color for primary text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryTextColor Color
Text color for secondary text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited