SolidThemeModeConfig class

Configuration for theme mode availability in the theme toggle cycle.

Constructors

SolidThemeModeConfig({bool lightModeEnabled = true, bool darkModeEnabled = true, bool systemModeEnabled = true, bool smartToggle = true})
const

Properties

darkModeEnabled bool
Whether dark mode is available in the toggle cycle.
final
enabledModes List<ThemeMode>
Returns the list of enabled theme modes.
no setter
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Validates that at least one mode is enabled.
no setter
lightModeEnabled bool
Whether light mode is available in the toggle cycle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smartToggle bool
Whether to use smart toggle behaviour when all three modes are enabled.
final
systemModeEnabled bool
Whether system mode is available in the toggle cycle.
final

Methods

copyWith({bool? lightModeEnabled, bool? darkModeEnabled, bool? systemModeEnabled, bool? smartToggle}) SolidThemeModeConfig
Creates a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited