logoutButtonTooltip function

String logoutButtonTooltip(
  1. String appName
)

Tooltip text for the LOGOUT button.

The appName parameter allows the tooltip to display the actual app name.

Implementation

String logoutButtonTooltip(String appName) =>
    'Tap here to logout from your connection to your Pod on the Solid server. '
    'Next time you start $appName you will need to log into the server again.';