InfoButtonStyle class

Constructors

InfoButtonStyle({bool visible = true, String text = defaultInfoButtonText, Color background = defaultButtonBackground, Color foreground = defaultButtonForeground, String tooltip = defaultInfoTooltip})
const

Properties

background Color
final
foreground Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
tooltip String
final
visible bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited