SolidAppBarAction class
Configuration for an AppBar action button.
Constructors
- SolidAppBarAction({String? id, required IconData icon, required VoidCallback onPressed, String? tooltip, Color? color, bool showOnNarrowScreen = true, bool showOnVeryNarrowScreen = true, int? initialIndex})
-
const
Properties
- color → Color?
-
Custom colour for the icon. If null, uses theme primary colour.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
The icon to display.
final
- id → String?
-
Unique identifier for this action. Used for ordering and visibility
settings in Preferences. If not provided, an auto-generated ID will be
used based on the action's position in the list.
final
- initialIndex → int?
-
Initial order index for this action. Lower values appear first (leftmost).
If not specified, the order will be based on the position in the actions
list. This can be overridden by user preferences.
final
- onPressed → VoidCallback
-
The callback when the button is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showOnNarrowScreen → bool
-
Whether this action should be shown on narrow screens.
final
- showOnVeryNarrowScreen → bool
-
Whether this action should be shown on very narrow screens.
final
- tooltip → String?
-
The tooltip message to show on hover/long press.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited