SolidLogin class

A widget to login to a Solid server for a user's token to access their POD.

Inheritance

Constructors

SolidLogin({required Widget child, bool required = false, String appDirectory = '', AssetImage image = const AssetImage('assets/images/default_image.jpg', package: 'solidpod'), String title = 'Log in to your Solid Pod', String webID = SolidConfig.defaultServerUrl, String link = 'https://solidproject.org', ContinueButtonStyle continueButtonStyle = const ContinueButtonStyle(), InfoButtonStyle infoButtonStyle = const InfoButtonStyle(), LoginButtonStyle loginButtonStyle = const LoginButtonStyle(), RegisterButtonStyle registerButtonStyle = const RegisterButtonStyle(), ChangeKeyButtonStyle changeKeyButtonStyle = const ChangeKeyButtonStyle(), SolidLoginTheme themeConfig = const SolidLoginTheme(), SnackbarConfig snackbarConfig = const SnackbarConfig(), List customFolderPathList = const [], Key? key})
const

Properties

appDirectory String
Directory name to consider when storing app data.
final
changeKeyButtonStyle ChangeKeyButtonStyle
The style of the CHANGE KEY button.
final
child Widget
The child widget after logging in.
final
continueButtonStyle ContinueButtonStyle
The style of the CONTINUE button.
final
customFolderPathList List
Custom list of folders to be created inside the data folder.
final
hashCode int
The hash code for this object.
no setterinherited
image AssetImage
The app's welcome image used as the left panel or the background, and the app's logo as displayed at the top of the login panel.
final
infoButtonStyle InfoButtonStyle
The style of the INFO button.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
The login text indicating what we are loging in to, the URI of the user's webID used to identify the Solid server to authenticate against, and the URL used as the value of the Visit link. Visit the link by clicking info button.
final
loginButtonStyle LoginButtonStyle
The style of the LOGIN button.
final
The app's welcome image used as the left panel or the background, and the app's logo as displayed at the top of the login panel.
final
registerButtonStyle RegisterButtonStyle
The style of the REGISTER button.
final
required bool
The default is to require a Solid Pod authentication.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snackbarConfig SnackbarConfig
Snackbar configuration for login notifications.
final
themeConfig SolidLoginTheme
Theme configuration for the login panel.
final
title String
The login text indicating what we are loging in to, the URI of the user's webID used to identify the Solid server to authenticate against, and the URL used as the value of the Visit link. Visit the link by clicking info button.
final
webID String
The login text indicating what we are loging in to, the URI of the user's webID used to identify the Solid server to authenticate against, and the URL used as the value of the Visit link. Visit the link by clicking info button.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SolidLogin>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited