SolidSecurityKeyCentralManager class
Central manager for security key operations to prevent duplicate prompts.
This singleton keeps track of security key verification status and ensures that the key is only requested once during app initialisation.
Constructors
- SolidSecurityKeyCentralManager()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ensureSecurityKey(
BuildContext context, Widget child) → Future< bool> - Checks if security key is needed and initiates a single verification process.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Reset the key verification status.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → SolidSecurityKeyCentralManager
-
no setter