WindowSize class
Responsive layout helpers using LayoutBuilder constraints.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isNarrowWindow(
BoxConstraints constraints) → bool - Legacy method — equivalent to isVeryNarrow.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isMedium(
BoxConstraints constraints, {double narrowThreshold = NavigationConstants.narrowScreenThreshold, double wideThreshold = NavigationConstants.wideScreenThreshold}) → bool -
Whether
constraintswidth falls in the medium range, i.e. betweennarrowThreshold(inclusive) andwideThreshold(exclusive). -
isNarrow(
BoxConstraints constraints, {double veryNarrowThreshold = NavigationConstants.veryNarrowScreenThreshold, double narrowThreshold = NavigationConstants.narrowScreenThreshold}) → bool -
Whether
constraintswidth falls in the narrow range, i.e. betweenveryNarrowThreshold(inclusive) andnarrowThreshold(exclusive). -
isVeryNarrow(
BoxConstraints constraints, {double threshold = NavigationConstants.veryNarrowScreenThreshold}) → bool -
Whether
constraintswidth is below the very narrow threshold. -
isVeryWide(
BoxConstraints constraints, {double threshold = NavigationConstants.veryWideScreenThreshold}) → bool -
Whether
constraintswidth exceeds the very wide threshold. -
isWide(
BoxConstraints constraints, {double wideThreshold = NavigationConstants.wideScreenThreshold, double veryWideThreshold = NavigationConstants.veryWideScreenThreshold}) → bool -
Whether
constraintswidth falls in the wide range, i.e. betweenwideThreshold(inclusive) andveryWideThreshold(exclusive).
Constants
- smallHeightLimit → const double
- Small height threshold.
- smallWidthLimit → const double
- Small width threshold.